@@ -1,7 +1,9 @@
 // SPDX-License-Identifier: MIT
 
-use crate::{Handle, NeighbourAddRequest, NeighbourDelRequest, NeighbourGetRequest};
-use netlink_packet_route::NeighbourMessage;
+use crate::{
+    Handle, NeighbourAddRequest, NeighbourDelRequest, NeighbourGetRequest,
+};
+use netlink_packet_route::neighbour::NeighbourMessage;
 use std::net::IpAddr;
 
 pub struct NeighbourHandle(Handle);
@@ -21,6 +23,7 @@ impl NeighbourHandle {
         NeighbourAddRequest::new(self.0.clone(), index, destination)
     }
 
+    #[cfg(not(target_os = "freebsd"))]
     /// Add a new fdb entry (equivalent to `bridge fdb add`)
     pub fn add_bridge(&self, index: u32, lla: &[u8]) -> NeighbourAddRequest {
         NeighbourAddRequest::new_bridge(self.0.clone(), index, lla)
