@@ -1,12 +1,12 @@
 // SPDX-License-Identifier: MIT
 
 use futures::stream::StreamExt;
-
-use crate::{
-    packet::{NetlinkMessage, NetlinkPayload, RouteMessage, RtnlMessage, NLM_F_ACK, NLM_F_REQUEST},
-    Error,
-    Handle,
+use netlink_packet_core::{
+    NetlinkMessage, NetlinkPayload, NLM_F_ACK, NLM_F_REQUEST,
 };
+use netlink_packet_route::{route::RouteMessage, RouteNetlinkMessage};
+
+use crate::{Error, Handle};
 
 pub struct RouteDelRequest {
     handle: Handle,
@@ -25,7 +25,8 @@ impl RouteDelRequest {
             message,
         } = self;
 
-        let mut req = NetlinkMessage::from(RtnlMessage::DelRoute(message));
+        let mut req =
+            NetlinkMessage::from(RouteNetlinkMessage::DelRoute(message));
         req.header.flags = NLM_F_REQUEST | NLM_F_ACK;
         let mut response = handle.request(req)?;
         while let Some(msg) = response.next().await {
