@@ -1,12 +1,10 @@
 // SPDX-License-Identifier: MIT
-use futures::StreamExt;
 
-use crate::{
-    packet::{NetlinkMessage, RtnlMessage, TcMessage, NLM_F_ACK, NLM_F_REQUEST},
-    try_nl,
-    Error,
-    Handle,
-};
+use futures::StreamExt;
+use netlink_packet_core::{NetlinkMessage, NLM_F_ACK, NLM_F_REQUEST};
+use netlink_packet_route::{tc::TcMessage, RouteNetlinkMessage};
+
+use crate::{try_nl, Error, Handle};
 
 pub struct QDiscDelRequest {
     handle: Handle,
@@ -25,7 +23,9 @@ impl QDiscDelRequest {
             message,
         } = self;
 
-        let mut req = NetlinkMessage::from(RtnlMessage::DelQueueDiscipline(message));
+        let mut req = NetlinkMessage::from(
+            RouteNetlinkMessage::DelQueueDiscipline(message),
+        );
         req.header.flags = NLM_F_REQUEST | NLM_F_ACK;
 
         let mut response = handle.request(req)?;
